@@ -184,8 +184,9 @@ parser.add_argument(
     help = 'If we are using an hdf5 file, give the column-wise IDs in this new line delimeted file',
     type = str)
 
-
-
+parser.add_argument("-heatmap_name",
+                    default = "genes_of_interest_subset_heatmap",
+                    type=str)
 
 args = parser.parse_args()
 ##############################################################
@@ -362,7 +363,7 @@ else:
     row_names = read_file(args.ID_list,'lines')
     title = read_file(args.columns,'lines')
     print('making a maliable hdf5 file to preserve the original data')
-    cmd('cp '+args.infile+' '+args.infile+'_copy')
+    cp(args.infile+' '+args.infile+'_copy')
     import h5py
     print('reading in hdf5 file')
     infile_path = args.infile+'_copy'
@@ -592,7 +593,8 @@ try:
         col_colors = reordered_colors_subset,
         yticklabels = True,
         #xticklabels=xticklabels,
-        cmap=global_cmap)
+        cmap=global_cmap,
+        metric="cosine")
 except:
     ## if it were too big to plot successfully, just do a subset
     sample = np.arange((np.shape(subset_df)[0]))
@@ -605,7 +607,8 @@ except:
         col_colors = reordered_colors_subset,
         yticklabels = True,
         #xticklabels=xticklabels,
-        cmap=global_cmap)
+        cmap=global_cmap,
+        metric="cosine")
 
 ## this sets the heatmap labels on the x axis
 sub.ax_heatmap.xaxis.set_ticks(indices_to_plot_for_names)
@@ -616,7 +619,7 @@ plt.setp(sub.ax_heatmap.xaxis.get_majorticklabels(), rotation=90)
 
 # plt.tight_layout()
 # plt.show()
-plt.savefig(args.out_dir+'genes_of_interest_subset_heatmap.png',
+plt.savefig(args.out_dir+args.heatmap_name+'.png',
     dpi=600,
     bbox_inches='tight')
 
